==> hibernate-core-6.2.13.Final-sources.jar: org/hibernate/sql/results/graph/embeddable/internal/NonAggregatedIdentifierMappingFetch.java <==
/*
 * Hibernate, Relational Persistence for Idiomatic Java
 *
 * License: GNU Lesser General Public License (LGPL), version 2.1 or later
 * See the lgpl.txt file in the root directory or http://www.gnu.org/licenses/lgpl-2.1.html
 */
package org.hibernate.sql.results.graph.embeddable.internal;

import org.hibernate.engine.FetchTiming;
import org.hibernate.metamodel.mapping.NonAggregatedIdentifierMapping;
import org.hibernate.spi.NavigablePath;
import org.hibernate.sql.results.graph.AssemblerCreationState;
import org.hibernate.sql.results.graph.DomainResultCreationState;
import org.hibernate.sql.results.graph.FetchParent;
import org.hibernate.sql.results.graph.FetchParentAccess;
import org.hibernate.sql.results.graph.Initializer;
import org.hibernate.sql.results.graph.embeddable.EmbeddableResultGraphNode;

public class NonAggregatedIdentifierMappingFetch extends EmbeddableFetchImpl {
	public NonAggregatedIdentifierMappingFetch(
			NavigablePath navigablePath,
			NonAggregatedIdentifierMapping embeddedPartDescriptor,
			FetchParent fetchParent,
			FetchTiming fetchTiming,
			boolean hasTableGroup,
			DomainResultCreationState creationState) {
		super( navigablePath, embeddedPartDescriptor, fetchParent, fetchTiming, hasTableGroup, creationState );
	}

	public NonAggregatedIdentifierMappingFetch(EmbeddableFetchImpl original) {
		super( original );
	}

	@Override
	protected Initializer buildEmbeddableFetchInitializer(
			FetchParentAccess parentAccess,
			EmbeddableResultGraphNode embeddableFetch,
			AssemblerCreationState creationState) {
		return new NonAggregatedIdentifierMappingFetchInitializer( parentAccess, this, creationState );
	}
}

==> hibernate-core-6.5.0.Final-sources.jar: org/hibernate/sql/results/graph/embeddable/internal/NonAggregatedIdentifierMappingFetch.java <==
/*
 * Hibernate, Relational Persistence for Idiomatic Java
 *
 * License: GNU Lesser General Public License (LGPL), version 2.1 or later
 * See the lgpl.txt file in the root directory or http://www.gnu.org/licenses/lgpl-2.1.html
 */
package org.hibernate.sql.results.graph.embeddable.internal;

import org.hibernate.engine.FetchTiming;
import org.hibernate.metamodel.mapping.NonAggregatedIdentifierMapping;
import org.hibernate.spi.NavigablePath;
import org.hibernate.sql.results.graph.AssemblerCreationState;
import org.hibernate.sql.results.graph.DomainResultCreationState;
import org.hibernate.sql.results.graph.FetchParent;
import org.hibernate.sql.results.graph.FetchParentAccess;
import org.hibernate.sql.results.graph.embeddable.EmbeddableInitializer;

public class NonAggregatedIdentifierMappingFetch extends EmbeddableFetchImpl {
	public NonAggregatedIdentifierMappingFetch(
			NavigablePath navigablePath,
			NonAggregatedIdentifierMapping embeddedPartDescriptor,
			FetchParent fetchParent,
			FetchTiming fetchTiming,
			boolean hasTableGroup,
			DomainResultCreationState creationState) {
		super( navigablePath, embeddedPartDescriptor, fetchParent, fetchTiming, hasTableGroup, creationState );
	}

	public NonAggregatedIdentifierMappingFetch(EmbeddableFetchImpl original) {
		super( original );
	}

	@Override
	public EmbeddableInitializer createInitializer(
			FetchParentAccess parentAccess,
			AssemblerCreationState creationState) {
		return new NonAggregatedIdentifierMappingFetchInitializer( parentAccess, this, creationState );
	}
}
